# 1 and 9
TERMINAL_INDICES = [0, 8, 9, 17, 18, 26]

# dragons and winds
EAST = 27
SOUTH = 28
WEST = 29
NORTH = 30
HAKU = 31
HATSU = 32
CHUN = 33

WINDS = [EAST, SOUTH, WEST, NORTH]
HONOR_INDICES = WINDS + [HAKU, HATSU, CHUN]

FIVE_RED_MAN = 16
FIVE_RED_PIN = 52
FIVE_RED_SOU = 88

AKA_DORA_LIST = [FIVE_RED_MAN, FIVE_RED_PIN, FIVE_RED_SOU]

DISPLAY_WINDS = {
    EAST: 'East',
    SOUTH: 'South',
    WEST: 'West',
    NORTH: 'North'
}
